The associations calcuated using this method can be asymmetric. In this case, the interaction radii for two given individuals would be different, implying that the proportion of the overlap between the zones for the individuals is different for each individual. As as example, Figure 1 illustrates the effect of different interaction radii per individual. Individual i is represented by the filled square and individual j is represented by the filled circle. The percentage of the overlap between the two territorial zones in the total area of territorial zone i is larger than that in territorial j, suggesting that the effect of individual j on i is greater than that of i on j.
The calculations are done based on a Monte Carlo method.
asymmetry.jpeg
calculate.areas(arg1, arg2, arg3, numpts)