calculateassociations: Generates social network based on xy spatial coordinates of individuals.
Description
This method uses the pairwise distances between each pair
of individuals. For a spatial point pattern X, the
association of individual j on individual i, Aij, is
calculated using the distances between points X_i and
X_j using a smooth interaction function first introduced
by Illian (2009). If d represents the distance between
points X_i and X_j, and the interaction radius for
individual i is R_i, then the association of j on i is
calculated as: ((1-(d/R_i)^2))^2 if d>0 and d<=r_i, 0="" and="" otherwise.="" this="" function="" has="" been="" described="" as="" a="" smooth="" interaction="" because="" the="" value="" of="" association="" calculated="" decreases="" smoothly="" distance.="" is="" in="" contrast="" to="" associations="" calcuated="" using="" binary="" where="" if="" d<="R" such="" based="" on="" assumption="" that="" constant="" (1)="" at="" all="" distances="" less="" than="" r_i,="" for="" greater="" r_i.="" figure="" below="" shows="" plot="" both="" functions="" (the="" represented="" by="" dotted="" line)="" an="" example="" r="1.
smooth.jpeg
=r_i,>
Usage
calculateassociations(x, y, ir)
Arguments
x
a list of x coordinates for all the individuals
y
a list of y coordinates for all the individuals
ir
a list of interaction radii for all the
individuals
References
Illian, Moller, Waagepetersen, 2009. Hierarchical spatial
point process analysis for a plant community of high
biodiversity.Environ. Ecol. Stat. vol 16, pp 389-405